#include <errno.h>
#include <fcntl.h>
#include <stdio.h>
#include <string.h>
#include <linux/cdrom.h>
#include <sys/ioctl.h>
#include <sys/types.h>
#include <sys/stat.h>

int main(int argc, char *argv[]) {
	int f;
	unsigned long int stat;
	int quiet = 0;

	if (argc < 3 || argc > 4 || (argc == 4 && strcmp(argv[1], "-q"))) {
		fprintf(stderr, "usage: cdcap [-q] <--cdr|--cdrw|--dvd|--dvdr|--dvdram> <device file>\n");
		return -1;
	}

	if (argc == 4) {
		quiet = 1;
		argv++;
	}

	if ((f = open(argv[2], O_RDONLY|O_NONBLOCK)) == -1) {
		if (!quiet)
			fprintf(stderr, "%s: %s\n", argv[2], strerror(errno));
		return -1;
	}
	if ((stat = ioctl(f, CDROM_GET_CAPABILITY)) == -1) {
		if (!quiet)
			fprintf(stderr, "%s: %s\n", argv[2], strerror(errno));
		return -1;
	}

	return !(
		(!strcmp(argv[1],"--cdr")    && (stat & CDC_CD_R))  ||
		(!strcmp(argv[1],"--cdrw")   && (stat & CDC_CD_RW)) ||
		(!strcmp(argv[1],"--dvd")    && (stat & CDC_DVD))   ||
		(!strcmp(argv[1],"--dvdr")   && (stat & CDC_DVD_R)) ||
		(!strcmp(argv[1],"--dvdram") && (stat & CDC_DVD_RAM))
	);
}
